##  3. What is a local storage object?
A local storage is a file created by a website in your device. Cookies are just one type of local storage, but there are others. It is important that you know them so you can block them or delete the data stored by them:
  * Browser local storage. Some websites use the browser's "sessionStorage" and "localStorage" to store data; "sessionStorage" is stored temporarily, but the “localStorage” is persistent. You may erase them by deleting your browser's history.
  * Flash local storage ("Flash Local Shared Objects"). Flash is a browser plug-in used to add Interactive and multimedia content into websites. Flash can store data in your device.
  * A web beacon is a tracking method that consists of an image embedded into a website. When your browser connects to the server where the image is located to download it, your access is tracked. Some times web beacons are very small or transparent images so the user is not aware of them.
